## System information

<!-- Can be obtained by running: ``python -c "import conkit; print(conkit.__version__)"`` -->
- PyJob version: <ADD HERE>
- Python version: <ADD HERE>
- Environment (if applicable): <ADD HERE>
<!-- Such as CCP4, Anaconda, CCP-EM, etc. -->

## Problem description

<!-- The description of the problem here -->

## Example

<!-- A minimal example to reproduce the error -->
```bash
<PASTE HERE>
```

## Traceback

<!-- The Python traceback -->
```python
<PASTE HERE>
```
